#!/bin/sh

if [ $# != 2 ]; then
    echo "Usage: create_pool.sh {-source | -derived | -cleartext} pool-name"
    exit 1
fi
kind=$1
name=$2

TMPFILE=/usr/tmp/xclearcase.$$
YES=0
NO=1

abort () {
    echo "Command aborted."
    rm -f $TMPFILE
    exit 1
}

# Ask user where to create pool
question="Can create pool under VOB storage directory or at another location.
Create pool under VOB?"
clearprompt yes_no -type ok -default yes -mask yes,no,abort \
    	-prefer_gui -prompt "$question"
answer=$?

# create pool under VOB (mkpool default)
if [ $answer = $YES ]; then
    :
# create pool elsewhere
elif [ $answer = $NO ]; then
    if clearprompt text -prefer_gui -outfile $TMPFILE \
                   -prompt "Enter pool pathname:" ; then
        pname=`cat $TMPFILE`
	rm -f $TMPFILE
        ln_opt="-ln $pname"
    else
	abort
    fi
# abort
else
    abort
fi

# Ask for pool parameters
if [ "$kind" != "-source" ]; then
    question="Use default pool size and age parameters?"
    clearprompt yes_no -prefer_gui -type ok -mask yes,no,abort \
		-prompt "$question" -default yes 
    answer=$?
    if [ $answer = $YES ]; then
	:
    elif [ $answer = $NO ]; then

	# age
	if clearprompt text -prefer_gui -outfile $TMPFILE \
		       -prompt "Enter age in hours:" -default "96" ; then
	    age=`cat $TMPFILE`
	    rm -f $TMPFILE
            age_opt="-age $age"
	else
	    abort
	fi

	# max size
	size_opt="-size"
	if clearprompt text -prefer_gui -outfile $TMPFILE \
		       -prompt "Enter max size in kbytes:" -default "0" ; then
	    size=`cat $TMPFILE`
	    rm -f $TMPFILE
            size_opt="$size_opt $size"
	else
	    abort
	fi

	# reclaim size
	if clearprompt text -prefer_gui -outfile $TMPFILE \
		       -prompt "Enter target size in kbytes:" -default "0" ; then
	    size=`cat $TMPFILE`
	    rm -f $TMPFILE
            size_opt="$size_opt $size"
	else
	    abort
	fi
    else
	abort
    fi
fi

cleartool mkpool $kind $ln_opt $age_opt $size_opt $name
